@@ -1,7 +1,7 @@
 
 package Net::OpenID::Common;
 BEGIN {
-  $Net::OpenID::Common::VERSION = '1.14';
+  $Net::OpenID::Common::VERSION = '1.15';
 }
 
 =head1 NAME
@@ -10,7 +10,7 @@ Net::OpenID::Common - Libraries shared between Net::OpenID::Consumer and Net::Op
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 DESCRIPTION
 
@@ -22,9 +22,21 @@ This package is Copyright (c) 2005 Brad Fitzpatrick, and (c) 2008 Martin Atkins.
 
 You may distribute under the terms of either the GNU General Public License or the Artistic License, as specified in the Perl README file. If you need more liberal licensing terms, please contact the maintainer.
 
+=head1 AUTHORS
+
+Brad Fitzpatrick <brad@danga.com>
+
+Tatsuhiko Miyagawa <miyagawa@sixapart.com>
+
+Martin Atkins <mart@degeneration.co.uk>
+
+Robert Norris <rob@eatenbyagrue.org>
+
+Roger Crew <crew@cs.stanford.edu>
+
 =head1 MAINTAINER
 
-Maintained by Martin Atkins <mart@degeneration.co.uk>
+Maintained by Roger Crew <crew@cs.stanford.edu>
 
 =cut
 
@@ -33,7 +45,7 @@ Maintained by Martin Atkins <mart@degeneration.co.uk>
 # like this to avoid confusion.
 package OpenID::util;
 BEGIN {
-  $OpenID::util::VERSION = '1.14';
+  $OpenID::util::VERSION = '1.15';
 }
 
 use Crypt::DH::GMP;
