@@ -6,7 +6,7 @@ Net::OpenID::URIFetch - fetch and cache content from HTTP URLs
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 DESCRIPTION
 
@@ -23,20 +23,15 @@ isn't much use outside of it. See URI::Fetch for a more general module.
 =cut
 
 package Net::OpenID::URIFetch;
-BEGIN {
-  $Net::OpenID::URIFetch::VERSION = '1.14';
+{
+  $Net::OpenID::URIFetch::VERSION = '1.15';
 }
 
 use HTTP::Request;
 use HTTP::Status;
 use strict;
 use warnings;
-use Carp;
-
-our $HAS_ZLIB;
-BEGIN {
-    $HAS_ZLIB = eval "use Compress::Zlib (); 1;";
-}
+use Carp();
 
 use constant URI_OK                => 200;
 use constant URI_MOVED_PERMANENTLY => 301;
@@ -95,9 +90,7 @@ sub fetch {
     }
 
     my $req = HTTP::Request->new(GET => $uri);
-    if ($HAS_ZLIB) {
-        $req->header('Accept-Encoding', 'gzip');
-    }
+    $req->header('Accept-Encoding', scalar HTTP::Message::decodable());
     if ($ref) {
         if (my $etag = ($ref->{Headers}->{etag})) {
             $req->header('If-None-Match', $etag);
@@ -119,13 +112,12 @@ sub fetch {
         return $cached_response->();
     }
     else {
-        my $content = $res->content;
         my $final_uri = $res->request->uri->as_string();
         my $final_cache_key = "URIFetch:${prefix}:${final_uri}";
 
-        if ($res->content_encoding && $res->content_encoding eq 'gzip') {
-            $content = Compress::Zlib::memGunzip($content);
-        }
+        my $content = $res->decoded_content             # Decode content-encoding and charset
+            || $res->decoded_content(charset => 'none') # Decode content-encoding
+            || $res->content;                           # Undecoded content
 
         if ($content_hook) {
             $content_hook->(\$content);
@@ -163,8 +155,8 @@ sub fetch {
 }
 
 package Net::OpenID::URIFetch::Response;
-BEGIN {
-  $Net::OpenID::URIFetch::Response::VERSION = '1.14';
+{
+  $Net::OpenID::URIFetch::Response::VERSION = '1.15';
 }
 
 use strict;
@@ -192,4 +184,4 @@ sub header {
     return $_[0]->{headers}{lc($_[1])};
 }
 
-1;
\ No newline at end of file
+1;
